@@ -1,4 +1,24 @@
-"LDheatmap" <- function (gdat, map.distance=1000*(1:ncol(gdat)), 
+# LDheatmap - Plots measures of pairwise linkage disequilibria for SNPs
+# Copyright (C) 2004  J.Shin, S. Blay, J.Graham, B.McNeney
+
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+########################################################################
+
+"LDheatmap" <- function 
+(gdat, map.distance=1000*(1:ncol(gdat)), 
                         distances="physical", LDmeas="r", 
                         title=NULL, add.map=TRUE, x.image.show = 0.2,
                         y.image.show = 0.2, line.position=0.2, 
